@@ -39,8 +39,6 @@
 #include "formats/outputformat.h"
 #include "formats/textdemux/textdemux.h"
 #include "helpers/commondefs.h"
-#include "helpers/fileloadhelper.h"
-#include "helpers/filesavehelper.h"
 #include "gui/treeview/lineswidget.h"
 #include "mainwindow.h"
 #include "gui/playerwidget.h"
@@ -141,7 +139,6 @@ Application::Application(int &argc, char **argv) :
 	m_translationMode(false),
 	m_textDemux(nullptr),
 	m_speechProcessor(nullptr),
-	m_lastFoundLine(nullptr),
 	m_lastSubtitleUrl(QDir::homePath()),
 	m_lastVideoUrl(QDir::homePath()),
 	m_linkCurrentLineToPosition(false)
