@@ -1,10 +1,12 @@
 /*
-    SPDX-FileCopyrightText: 2010-2019 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2010-2022 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "application.h"
+
+#include "appglobal.h"
 #include "actions/kcodecactionext.h"
 #include "actions/krecentfilesactionext.h"
 #include "actions/useractionnames.h"
@@ -28,10 +30,11 @@
 #include <QStringBuilder>
 #include <QTextCodec>
 
-#include <KCharsets>
 #include <KCodecAction>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <kwidgetsaddons_version.h>
+
 
 #undef ERROR
 
@@ -72,8 +75,8 @@ Application::buildSubtitleFilesFilter(bool openFileFilter)
 				filterSave += formatLine;
 			}
 		}
-		filterOpen = i18n("All Text Subtitles") % $(" (") % textExtensions.midRef(1) % $(")\n")
-			% i18n("All Image Subtitles") % $(" (") % imageExtensions.midRef(1) % $(")\n")
+		filterOpen = i18n("All Text Subtitles") % $(" (") % QStringView(textExtensions).mid(1) % $(")\n")
+			% i18n("All Image Subtitles") % $(" (") % QStringView(imageExtensions).mid(1) % $(")\n")
 			% filterSave
 			% i18n("All Files") % $(" (*)");
 		filterSave.truncate(filterSave.size() - 1);
@@ -96,9 +99,9 @@ Application::buildMediaFilesFilter()
 		foreach(const QString ext, audioExtensionList)
 			audioExtensions += $(" *.") % ext;
 
-		filter = i18n("Media Files") % $(" (") % videoExtensions.midRef(1) % audioExtensions % $(")\n")
-			% i18n("Video Files") % $(" (") % videoExtensions.midRef(1) % $(")\n")
-			% i18n("Audio Files") % $(" (") % audioExtensions.midRef(1) % $(")\n")
+		filter = i18n("Media Files") % $(" (") % QStringView(videoExtensions).mid(1) % audioExtensions % $(")\n")
+			% i18n("Video Files") % $(" (") % QStringView(videoExtensions).mid(1) % $(")\n")
+			% i18n("Audio Files") % $(" (") % QStringView(audioExtensions).mid(1) % $(")\n")
 			% i18n("All Files") % $(" (*)");
 	}
 
@@ -110,13 +113,7 @@ Application::codecForEncoding(const QString &encoding)
 {
 	if(encoding.isEmpty())
 		return nullptr;
-
-	bool codecFound = false;
-	QTextCodec *codec = KCharsets::charsets()->codecForName(encoding, codecFound);
-	if(!codecFound)
-		return nullptr;
-
-	return codec;
+	return QTextCodec::codecForName(encoding.toUtf8());
 }
 
 bool
@@ -139,7 +136,7 @@ Application::newSubtitle()
 	if(!closeSubtitle())
 		return;
 
-	m_subtitle = new Subtitle();
+	AppGlobal::subtitle = new Subtitle();
 	m_subtitleUrl.clear();
 
 	processSubtitleOpened(nullptr, QString());
@@ -154,7 +151,7 @@ Application::openSubtitle()
 	openDlg.selectUrl(m_lastSubtitleUrl);
 
 	if(openDlg.exec() == QDialog::Accepted)
-		openSubtitle(openDlg.selectedUrls().first());
+		openSubtitle(openDlg.selectedUrls().constFirst());
 }
 
 void
@@ -170,8 +167,8 @@ Application::openSubtitle(const QUrl &url, bool warnClashingUrls)
 
 	QTextCodec *codec = codecForEncoding(KRecentFilesActionExt::encodingForUrl(url));
 
-	m_subtitle = new Subtitle();
-	FormatManager::Status res = FormatManager::instance().readSubtitle(*m_subtitle, true, url, &codec, &m_subtitleFormat);
+	AppGlobal::subtitle = new Subtitle();
+	FormatManager::Status res = FormatManager::instance().readSubtitle(*appSubtitle(), true, url, &codec, &m_subtitleFormat);
 	if(res == FormatManager::SUCCESS) {
 		m_subtitleUrl = url;
 		processSubtitleOpened(codec, m_subtitleFormat);
@@ -199,10 +196,10 @@ Application::openSubtitle(const QUrl &url, bool warnClashingUrls)
 			}
 		}
 	} else {
-		m_subtitle.reset();
+		AppGlobal::subtitle.reset();
 
 		if(res == FormatManager::ERROR) {
-			KMessageBox::sorry(
+			KMessageBox::error(
 				m_mainWindow,
 				i18n("<qt>Could not parse the subtitle file.<br/>"
 					 "This may have been caused by usage of the wrong encoding.</qt>"));
@@ -222,7 +219,7 @@ Application::reopenSubtitleWithCodec(QTextCodec *codec)
 	FormatManager::Status res = FormatManager::instance().readSubtitle(*subtitle, true, m_subtitleUrl, &codec, &subtitleFormat);
 	if(res != FormatManager::SUCCESS) {
 		if(res == FormatManager::ERROR) {
-			KMessageBox::sorry(
+			KMessageBox::error(
 				m_mainWindow,
 				i18n("<qt>Could not parse the subtitle file.<br/>"
 					 "This may have been caused by usage of the wrong encoding.</qt>"));
@@ -234,9 +231,9 @@ Application::reopenSubtitleWithCodec(QTextCodec *codec)
 	emit subtitleClosed();
 
 	if(m_translationMode)
-		subtitle->setSecondaryData(*m_subtitle, false);
+		subtitle->setSecondaryData(*appSubtitle(), false);
 
-	m_subtitle = subtitle;
+	AppGlobal::subtitle = subtitle;
 
 	processSubtitleOpened(codec, subtitleFormat);
 }
@@ -245,18 +242,18 @@ void
 Application::processSubtitleOpened(QTextCodec *codec, const QString &subtitleFormat)
 {
 	// The loading of the subtitle shouldn't be an undoable action as there's no state before it
-	m_undoStack->clear();
-	m_subtitle->clearPrimaryDirty();
-	m_subtitle->clearSecondaryDirty();
+	appUndoStack()->clear();
+	appSubtitle()->clearPrimaryDirty();
+	appSubtitle()->clearSecondaryDirty();
 
-	emit subtitleOpened(m_subtitle.data());
+	emit subtitleOpened(appSubtitle());
 
 	m_subtitleFormat = subtitleFormat;
 
 	if(m_subtitleUrl.isEmpty()) {
 		m_subtitleFileName.clear();
-		m_subtitleEncoding = SCConfig::defaultSubtitlesEncoding();
-		codec = KCharsets::charsets()->codecForName(m_subtitleEncoding);
+		m_subtitleEncoding = SCConfig::defaultSubtitlesEncoding().toUtf8();
+		codec = QTextCodec::codecForName(m_subtitleEncoding.toUtf8());
 	} else {
 		m_subtitleFileName = QFileInfo(m_subtitleUrl.path()).fileName();
 		Q_ASSERT(codec != nullptr);
@@ -266,8 +263,8 @@ Application::processSubtitleOpened(QTextCodec *codec, const QString &subtitleFor
 	m_reopenSubtitleAsAction->setCurrentCodec(codec);
 	m_saveSubtitleAsAction->setCurrentCodec(codec);
 
-	connect(m_subtitle.constData(), &Subtitle::primaryDirtyStateChanged, this, &Application::updateTitle);
-	connect(m_subtitle.constData(), &Subtitle::secondaryDirtyStateChanged, this, &Application::updateTitle);
+	connect(appSubtitle(), &Subtitle::primaryDirtyStateChanged, this, &Application::updateTitle);
+	connect(appSubtitle(), &Subtitle::secondaryDirtyStateChanged, this, &Application::updateTitle);
 	updateTitle();
 
 	m_labSubFormat->setText(i18n("Format: %1", m_subtitleFormat));
@@ -282,7 +279,7 @@ Application::demuxTextStream(int textStreamIndex)
 
 	newSubtitle();
 
-	m_textDemux->demuxFile(m_subtitle.data(), VideoPlayer::instance()->filePath(), textStreamIndex);
+	m_textDemux->demuxFile(appSubtitle(), VideoPlayer::instance()->filePath(), textStreamIndex);
 }
 
 void
@@ -293,7 +290,7 @@ Application::speechImportAudioStream(int audioStreamIndex)
 
 	newSubtitle();
 
-	m_speechProcessor->setSubtitle(m_subtitle.data());
+	m_speechProcessor->setSubtitle(appSubtitle());
 	m_speechProcessor->setAudioStream(VideoPlayer::instance()->filePath(), audioStreamIndex);
 }
 
@@ -303,16 +300,15 @@ Application::saveSubtitle(QTextCodec *codec)
 	if(m_subtitleUrl.isEmpty() || !FormatManager::instance().hasOutput(m_subtitleFormat))
 		return saveSubtitleAs(codec);
 
-	bool codecFound = true;
 	if(!codec)
-		codec = KCharsets::charsets()->codecForName(m_subtitleEncoding, codecFound);
-	if(!codecFound)
-		codec = KCharsets::charsets()->codecForName(SCConfig::defaultSubtitlesEncoding(), codecFound);
-	if(!codecFound)
+		codec = QTextCodec::codecForName(m_subtitleEncoding.toUtf8());
+	if(!codec)
+		codec = QTextCodec::codecForName(SCConfig::defaultSubtitlesEncoding().toUtf8());
+	if(!codec)
 		codec = QTextCodec::codecForLocale();
 
-	if(FormatManager::instance().writeSubtitle(*m_subtitle, true, m_subtitleUrl, codec, m_subtitleFormat, true)) {
-		m_subtitle->clearPrimaryDirty();
+	if(FormatManager::instance().writeSubtitle(*appSubtitle(), true, m_subtitleUrl, codec, m_subtitleFormat, true)) {
+		appSubtitle()->clearPrimaryDirty();
 
 		m_reopenSubtitleAsAction->setCurrentCodec(codec);
 		m_saveSubtitleAsAction->setCurrentCodec(codec);
@@ -325,7 +321,7 @@ Application::saveSubtitle(QTextCodec *codec)
 
 		return true;
 	} else {
-		KMessageBox::sorry(m_mainWindow, i18n("There was an error saving the subtitle."));
+		KMessageBox::error(m_mainWindow, i18n("There was an error saving the subtitle."));
 		return false;
 	}
 }
@@ -362,28 +358,35 @@ Application::saveSubtitleAs(QTextCodec *codec)
 	return false;
 }
 
+#if KWIDGETSADDONS_VERSION < QT_VERSION_CHECK(5, 100, 0)
+#define warningTwoActionsCancel warningYesNoCancel
+#define PrimaryAction Yes
+#endif
+
 bool
 Application::closeSubtitle()
 {
-	if(m_subtitle) {
-		if(m_translationMode && m_subtitle->isSecondaryDirty()) {
-			int result = KMessageBox::warningYesNoCancel(nullptr,
+	if(appSubtitle()) {
+		if(m_translationMode && appSubtitle()->isSecondaryDirty()) {
+			KMessageBox::ButtonCode result = KMessageBox::warningTwoActionsCancel(nullptr,
 							i18n("Currently opened translation subtitle has unsaved changes.\nDo you want to save them?"),
-							i18n("Close Translation Subtitle") + " - SubtitleComposer");
+							i18n("Close Translation Subtitle") + " - SubtitleComposer",
+							KStandardGuiItem::save(), KStandardGuiItem::dontSave());
 			if(result == KMessageBox::Cancel)
 				return false;
-			else if(result == KMessageBox::Yes)
+			else if(result == KMessageBox::PrimaryAction)
 				if(!saveSubtitleTr())
 					return false;
 		}
 
-		if(m_subtitle->isPrimaryDirty()) {
-			int result = KMessageBox::warningYesNoCancel(nullptr,
+		if(appSubtitle()->isPrimaryDirty()) {
+			KMessageBox::ButtonCode result = KMessageBox::warningTwoActionsCancel(nullptr,
 							i18n("Currently opened subtitle has unsaved changes.\nDo you want to save them?"),
-							i18n("Close Subtitle") + " - SubtitleComposer");
+							i18n("Close Subtitle") + " - SubtitleComposer",
+							KStandardGuiItem::save(), KStandardGuiItem::dontSave());
 			if(result == KMessageBox::Cancel)
 				return false;
-			else if(result == KMessageBox::Yes)
+			else if(result == KMessageBox::PrimaryAction)
 				if(!saveSubtitle())
 					return false;
 		}
@@ -393,11 +396,14 @@ Application::closeSubtitle()
 			emit translationModeChanged(false);
 		}
 
-		m_undoStack->clear();
+		disconnect(appSubtitle(), &Subtitle::primaryDirtyStateChanged, this, &Application::updateTitle);
+		disconnect(appSubtitle(), &Subtitle::secondaryDirtyStateChanged, this, &Application::updateTitle);
 
 		emit subtitleClosed();
 
-		m_subtitle.reset();
+		appUndoStack()->clear();
+
+		AppGlobal::subtitle.reset();
 
 		m_labSubFormat->setText(QString());
 		m_labSubEncoding->setText(QString());
@@ -433,7 +439,7 @@ Application::newSubtitleTr()
 void
 Application::openSubtitleTr()
 {
-	if(!m_subtitle)
+	if(!appSubtitle())
 		return;
 
 	QFileDialog openDlg(m_mainWindow, i18n("Open Translation Subtitle"),  QString(), buildSubtitleFilesFilter());
@@ -450,7 +456,7 @@ Application::openSubtitleTr(const QUrl &url, bool warnClashingUrls)
 {
 	m_lastSubtitleUrl = url;
 
-	if(!m_subtitle)
+	if(!appSubtitle())
 		return;
 
 	if(warnClashingUrls && !acceptClashingUrls(m_subtitleUrl, url))
@@ -459,13 +465,13 @@ Application::openSubtitleTr(const QUrl &url, bool warnClashingUrls)
 	if(!closeSubtitleTr())
 		return;
 
-	Subtitle subtitleTr;
+	QExplicitlySharedDataPointer<Subtitle> subtitleTr(new Subtitle());
 	QTextCodec *codec = codecForEncoding(KRecentFilesActionExt::encodingForUrl(url));
 
-	FormatManager::Status res = FormatManager::instance().readSubtitle(subtitleTr, false, url, &codec, &m_subtitleTrFormat);
+	FormatManager::Status res = FormatManager::instance().readSubtitle(*subtitleTr, false, url, &codec, &m_subtitleTrFormat);
 	if(res != FormatManager::SUCCESS) {
 		if(res == FormatManager::ERROR) {
-			KMessageBox::sorry(
+			KMessageBox::error(
 				m_mainWindow,
 				i18n("<qt>Could not parse the subtitle file.<br/>"
 					 "This may have been caused by usage of the wrong encoding.</qt>"));
@@ -474,7 +480,7 @@ Application::openSubtitleTr(const QUrl &url, bool warnClashingUrls)
 	}
 
 	m_subtitleTrUrl = url;
-	m_subtitle->setSecondaryData(subtitleTr, false);
+	appSubtitle()->setSecondaryData(*subtitleTr, false);
 	processTranslationOpened(codec, m_subtitleTrFormat);
 }
 
@@ -484,13 +490,13 @@ Application::reopenSubtitleTrWithCodec(QTextCodec *codec)
 	if(m_subtitleTrUrl.isEmpty())
 		return;
 
-	Subtitle subtitleTr;
+	QExplicitlySharedDataPointer<Subtitle> subtitleTr(new Subtitle());
 	QString subtitleTrFormat;
 
-	FormatManager::Status res = FormatManager::instance().readSubtitle(subtitleTr, false, m_subtitleTrUrl, &codec, &subtitleTrFormat);
+	FormatManager::Status res = FormatManager::instance().readSubtitle(*subtitleTr, false, m_subtitleTrUrl, &codec, &subtitleTrFormat);
 	if(res != FormatManager::SUCCESS) {
 		if(res == FormatManager::ERROR) {
-			KMessageBox::sorry(
+			KMessageBox::error(
 				m_mainWindow,
 				i18n("<qt>Could not parse the subtitle file.<br/>"
 					 "This may have been caused by usage of the wrong encoding.</qt>"));
@@ -498,7 +504,7 @@ Application::reopenSubtitleTrWithCodec(QTextCodec *codec)
 		return;
 	}
 
-	m_subtitle->setSecondaryData(subtitleTr, false);
+	appSubtitle()->setSecondaryData(*subtitleTr, false);
 	processTranslationOpened(codec, m_subtitleTrFormat);
 }
 
@@ -507,7 +513,7 @@ Application::processTranslationOpened(QTextCodec *codec, const QString &subtitle
 {
 	// We don't clear the primary dirty state because the loading of the translation
 	// only changes it when actually needed (i.e., when the translation had more lines)
-	m_subtitle->clearSecondaryDirty();
+	appSubtitle()->clearSecondaryDirty();
 
 	m_subtitleFormat = subtitleFormat;
 
@@ -542,16 +548,15 @@ Application::saveSubtitleTr(QTextCodec *codec)
 	if(m_subtitleTrUrl.isEmpty() || !FormatManager::instance().hasOutput(m_subtitleTrFormat))
 		return saveSubtitleTrAs(codec);
 
-	bool codecFound = true;
 	if(!codec)
-		codec = KCharsets::charsets()->codecForName(m_subtitleTrEncoding, codecFound);
-	if(!codecFound)
-		codec = KCharsets::charsets()->codecForName(SCConfig::defaultSubtitlesEncoding(), codecFound);
-	if(!codecFound)
+		codec = QTextCodec::codecForName(m_subtitleTrEncoding.toUtf8());
+	if(!codec)
+		codec = QTextCodec::codecForName(SCConfig::defaultSubtitlesEncoding().toUtf8());
+	if(!codec)
 		codec = QTextCodec::codecForLocale();
 
-	if(FormatManager::instance().writeSubtitle(*m_subtitle, false, m_subtitleTrUrl, codec, m_subtitleTrFormat, true)) {
-		m_subtitle->clearSecondaryDirty();
+	if(FormatManager::instance().writeSubtitle(*appSubtitle(), false, m_subtitleTrUrl, codec, m_subtitleTrFormat, true)) {
+		appSubtitle()->clearSecondaryDirty();
 
 		m_reopenSubtitleTrAsAction->setCurrentCodec(codec);
 		m_saveSubtitleTrAsAction->setCurrentCodec(codec);
@@ -562,7 +567,7 @@ Application::saveSubtitleTr(QTextCodec *codec)
 
 		return true;
 	} else {
-		KMessageBox::sorry(m_mainWindow, i18n("There was an error saving the translation subtitle."));
+		KMessageBox::error(m_mainWindow, i18n("There was an error saving the translation subtitle."));
 		return false;
 	}
 }
@@ -603,14 +608,15 @@ Application::saveSubtitleTrAs(QTextCodec *codec)
 bool
 Application::closeSubtitleTr()
 {
-	if(m_subtitle && m_translationMode) {
-		if(m_translationMode && m_subtitle->isSecondaryDirty()) {
-			int result = KMessageBox::warningYesNoCancel(nullptr,
+	if(appSubtitle() && m_translationMode) {
+		if(m_translationMode && appSubtitle()->isSecondaryDirty()) {
+			KMessageBox::ButtonCode result = KMessageBox::warningTwoActionsCancel(nullptr,
 					i18n("Currently opened translation subtitle has unsaved changes.\nDo you want to save them?"),
-					i18n("Close Translation Subtitle") + " - SubtitleComposer");
+					i18n("Close Translation Subtitle") + " - SubtitleComposer",
+					KStandardGuiItem::save(), KStandardGuiItem::dontSave());
 			if(result == KMessageBox::Cancel)
 				return false;
-			else if(result == KMessageBox::Yes)
+			else if(result == KMessageBox::PrimaryAction)
 				if(!saveSubtitleTr())
 					return false;
 		}
@@ -620,16 +626,16 @@ Application::closeSubtitleTr()
 
 		updateTitle();
 
-		m_linesWidget->setUpdatesEnabled(false);
+		m_mainWindow->m_linesWidget->setUpdatesEnabled(false);
 
 		// The cleaning of the translations texts shouldn't be an undoable action
-//		QUndoStack *savedStack = m_undoStack;
-//		m_undoStack = new QUndoStack();
-		m_subtitle->clearSecondaryTextData();
-//		delete m_undoStack;
-//		m_undoStack = savedStack;
+//		QUndoStack *savedStack = appUndoStack();
+//		AppGlobal::undoStack = new QUndoStack();
+		appSubtitle()->clearSecondaryTextData();
+//		delete AppGlobal::undoStack;
+//		AppGlobal::undoStack = savedStack;
 
-		m_linesWidget->setUpdatesEnabled(true);
+		m_mainWindow->m_linesWidget->setUpdatesEnabled(true);
 	}
 
 	return true;
@@ -658,9 +664,8 @@ Application::saveSplitSubtitle(const Subtitle &subtitle, const QUrl &srcUrl, QSt
 		dstUrl.setPath(dstFileInfo.path());
 		dstUrl = System::newUrl(dstUrl, dstFileInfo.completeBaseName() + " - " + i18nc("Suffix added to split subtitles", "split"), dstFileInfo.suffix());
 
-		bool codecFound;
-		QTextCodec *codec = KCharsets::charsets()->codecForName(encoding, codecFound);
-		if(!codecFound)
+		QTextCodec *codec = QTextCodec::codecForName(encoding.toUtf8());
+		if(!codec)
 			codec = QTextCodec::codecForLocale();
 
 		if(FormatManager::instance().writeSubtitle(subtitle, primary, dstUrl, codec, format, false)) {
@@ -674,7 +679,7 @@ Application::saveSplitSubtitle(const Subtitle &subtitle, const QUrl &srcUrl, QSt
 	}
 
 	if(dstUrl.path().isEmpty()) {
-		KMessageBox::sorry(m_mainWindow, primary ? i18n("Could not write the split subtitle file.") : i18n("Could not write the split subtitle translation file."));
+		KMessageBox::error(m_mainWindow, primary ? i18n("Could not write the split subtitle file.") : i18n("Could not write the split subtitle translation file."));
 	}
 
 	return dstUrl;
@@ -686,20 +691,20 @@ Application::joinSubtitles()
 	static JoinSubtitlesDialog *dlg = new JoinSubtitlesDialog(m_mainWindow);
 
 	if(dlg->exec() == QDialog::Accepted) {
-		Subtitle secondSubtitle;
+		QExplicitlySharedDataPointer<Subtitle> secondSubtitle(new Subtitle());
 
 		const QUrl url = dlg->subtitleUrl();
 		QTextCodec *codec = codecForEncoding(KRecentFilesActionExt::encodingForUrl(url));
 		const bool primary = dlg->selectedTextsTarget() != Secondary;
 
-		FormatManager::Status res = FormatManager::instance().readSubtitle(secondSubtitle, primary, url, &codec, nullptr);
+		FormatManager::Status res = FormatManager::instance().readSubtitle(*secondSubtitle, primary, url, &codec, nullptr);
 		if(res == FormatManager::SUCCESS) {
 			if(dlg->selectedTextsTarget() == Both)
-				secondSubtitle.setSecondaryData(secondSubtitle, true);
+				secondSubtitle->setSecondaryData(*secondSubtitle, true);
 
-			m_subtitle->appendSubtitle(secondSubtitle, dlg->shiftTime().toMillis());
+			appSubtitle()->appendSubtitle(*secondSubtitle, dlg->shiftTime().toMillis());
 		} else {
-			KMessageBox::sorry(m_mainWindow, i18n("Could not read the subtitle file to append."));
+			KMessageBox::error(m_mainWindow, i18n("Could not read the subtitle file to append."));
 		}
 	}
 }
@@ -712,33 +717,33 @@ Application::splitSubtitle()
 	if(dlg->exec() != QDialog::Accepted)
 		return;
 
-	Subtitle newSubtitle;
-	m_subtitle->splitSubtitle(newSubtitle, dlg->splitTime().toMillis(), dlg->shiftNewSubtitle());
-	if(!newSubtitle.linesCount()) {
+	QExplicitlySharedDataPointer<Subtitle> newSubtitle(new Subtitle());
+	appSubtitle()->splitSubtitle(*newSubtitle, dlg->splitTime().toMillis(), dlg->shiftNewSubtitle());
+	if(!newSubtitle->linesCount()) {
 		KMessageBox::information(m_mainWindow, i18n("The specified time does not split the subtitles."));
 		return;
 	}
 
 	QUrl splitUrl = saveSplitSubtitle(
-		newSubtitle,
+		*newSubtitle,
 		m_subtitleUrl,
 		m_subtitleEncoding,
 		m_subtitleFormat,
 		true);
 
 	if(splitUrl.path().isEmpty()) {
-		// there was an error saving the split part, undo the splitting of m_subtitle
-		m_undoStack->undo();
+		// there was an error saving the split part, undo the splitting of appSubtitle()
+		appUndoStack()->undo();
 		return;
 	}
 
 	QUrl splitTrUrl;
 	if(m_translationMode) {
-		splitTrUrl = saveSplitSubtitle(newSubtitle, m_subtitleTrUrl, m_subtitleTrEncoding, m_subtitleTrFormat, false);
+		splitTrUrl = saveSplitSubtitle(*newSubtitle, m_subtitleTrUrl, m_subtitleTrEncoding, m_subtitleTrFormat, false);
 
 		if(splitTrUrl.path().isEmpty()) {
-			// there was an error saving the split part, undo the splitting of m_subtitle
-			m_undoStack->undo();
+			// there was an error saving the split part, undo the splitting of appSubtitle()
+			appUndoStack()->undo();
 			return;
 		}
 	}
@@ -749,7 +754,7 @@ Application::splitSubtitle()
 		args << splitTrUrl.toString(QUrl::PreferLocalFile);
 
 	if(!QProcess::startDetached(applicationName(), args)) {
-		KMessageBox::sorry(m_mainWindow, m_translationMode
+		KMessageBox::error(m_mainWindow, m_translationMode
 			? i18n("Could not open a new Subtitle Composer window.\n" "The split part was saved as %1.", splitUrl.path())
 			: i18n("Could not open a new Subtitle Composer window.\n" "The split parts were saved as %1 and %2.", splitUrl.path(), splitTrUrl.path()));
 	}
@@ -761,24 +766,24 @@ Application::syncWithSubtitle()
 	static SyncSubtitlesDialog *dlg = new SyncSubtitlesDialog(m_mainWindow);
 
 	if(dlg->exec() == QDialog::Accepted) {
-		Subtitle referenceSubtitle;
+		QExplicitlySharedDataPointer<Subtitle> referenceSubtitle(new Subtitle());
 
 		const QUrl url = dlg->subtitleUrl();
 
-		FormatManager::Status res = FormatManager::instance().readSubtitle(referenceSubtitle, true, url, nullptr, nullptr);
+		FormatManager::Status res = FormatManager::instance().readSubtitle(*referenceSubtitle, true, url, nullptr, nullptr);
 		if(res == FormatManager::SUCCESS) {
 			if(dlg->adjustToReferenceSubtitle()) {
-				if(referenceSubtitle.linesCount() <= 1)
-					KMessageBox::sorry(m_mainWindow, i18n("The reference subtitle must have more than one line to proceed."));
+				if(referenceSubtitle->linesCount() <= 1)
+					KMessageBox::error(m_mainWindow, i18n("The reference subtitle must have more than one line to proceed."));
 				else
-					m_subtitle->adjustLines(Range::full(),
-											referenceSubtitle.firstLine()->showTime().toMillis(),
-											referenceSubtitle.lastLine()->showTime().toMillis());
+					appSubtitle()->adjustLines(Range::full(),
+											referenceSubtitle->firstLine()->showTime().toMillis(),
+											referenceSubtitle->lastLine()->showTime().toMillis());
 			} else /*if(dlg->synchronizeToReferenceTimes())*/ {
-				m_subtitle->syncWithSubtitle(referenceSubtitle);
+				appSubtitle()->syncWithSubtitle(*referenceSubtitle);
 			}
 		} else {
-			KMessageBox::sorry(m_mainWindow, i18n("Could not parse the reference subtitle file."));
+			KMessageBox::error(m_mainWindow, i18n("Could not parse the reference subtitle file."));
 		}
 	}
 }
