@@ -14,6 +14,8 @@
 #include <QDialogButtonBox>
 #include <QPushButton>
 
+#include <KLocalizedString>
+
 using namespace SubtitleComposer;
 
 ProgressDialog::ProgressDialog(const QString &caption, const QString &description, bool allowCancel, QWidget *parent) :
@@ -31,6 +33,7 @@ ProgressDialog::ProgressDialog(const QString &caption, const QString &descriptio
 	m_label->setAlignment(Qt::AlignHCenter);
 
 	m_progressBar = new QProgressBar(this);
+	m_progressBar->setFormat(i18nc("%p is the percent value, % is the percent sign", "%p%"));
 	m_progressBar->setMaximum(1);
 	m_progressBar->setValue(0);
 
