@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2017-2018 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2017-2022 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,7 +7,7 @@
 #include "vobsubinputprocessdialog.h"
 #include "ui_vobsubinputprocessdialog.h"
 
-#include "core/richdocument.h"
+#include "core/richtext/richdocument.h"
 
 #include <functional>
 
@@ -21,6 +21,7 @@
 #include <QDataStream>
 #include <QFile>
 #include <QSaveFile>
+#include <QStringView>
 
 using namespace SubtitleComposer;
 
@@ -85,7 +86,7 @@ public:
 	LinePtr line;
 	qint32 top, left, bottom, right;
 	qint32 symbolCount;
-	SString text;
+	RichString text;
 	QVector<QPoint> pixels;
 };
 
@@ -247,12 +248,6 @@ VobSubInputProcessDialog::Frame::processPieces()
 	return true;
 }
 
-inline bool
-operator<(const VobSubInputProcessDialog::LinePtr &a, const VobSubInputProcessDialog::LinePtr &b)
-{
-	return a->top < b->top;
-}
-
 inline bool
 VobSubInputProcessDialog::Piece::operator<(const Piece &other) const
 {
@@ -367,17 +362,17 @@ VobSubInputProcessDialog::VobSubInputProcessDialog(Subtitle *subtitle, QWidget *
 	connect(ui->btnOk, &QPushButton::clicked, this, &VobSubInputProcessDialog::onOkClicked);
 	connect(ui->btnAbort, &QPushButton::clicked, this, &VobSubInputProcessDialog::onAbortClicked);
 
-	connect(ui->styleBold, &QPushButton::toggled, [this](bool checked){
+	connect(ui->styleBold, &QPushButton::toggled, this, [this](bool checked){
 		QFont font = ui->lineEdit->font();
 		font.setBold(checked);
 		ui->lineEdit->setFont(font);
 	});
-	connect(ui->styleItalic, &QPushButton::toggled, [this](bool checked){
+	connect(ui->styleItalic, &QPushButton::toggled, this, [this](bool checked){
 		QFont font = ui->lineEdit->font();
 		font.setItalic(checked);
 		ui->lineEdit->setFont(font);
 	});
-	connect(ui->styleUnderline, &QPushButton::toggled, [this](bool checked){
+	connect(ui->styleUnderline, &QPushButton::toggled, this, [this](bool checked){
 		QFont font = ui->lineEdit->font();
 		font.setUnderline(checked);
 		ui->lineEdit->setFont(font);
@@ -413,15 +408,15 @@ VobSubInputProcessDialog::symFileOpen(const QString &filename)
 	m_recognizedPieces.clear();
 	m_recognizedPiecesMaxSymbolLength = 0;
 
-	SString text;
+	RichString text;
 	Piece piece;
 	QString line;
 	QChar ch;
 	while(stream.readLineInto(&line)) {
 		if(line.startsWith(QStringLiteral(".s "))) {
-			text.setRichString(line.midRef(3).trimmed().toString());
+			text.setRichString(QStringView(line).mid(3).trimmed().toString());
 		} else if(line.startsWith(QStringLiteral(".d "))) {
-			QTextStream data(line.midRef(3).trimmed().toUtf8());
+			QTextStream data(QStringView(line).mid(3).trimmed().toUtf8());
 
 			// read piece data
 			data >> piece.right;
@@ -599,7 +594,7 @@ VobSubInputProcessDialog::onStreamFinished()
 
 	if(!Frame::spaceStats.empty()) {
 		auto itChar = Frame::spaceStats.begin(); // shorter spaces on start
-		auto itWord = Frame::spaceStats.end() - 1; // longer spaces near end
+		auto itWord = std::prev(Frame::spaceStats.end()); // longer spaces near end
 		qint64 charSpacingSum = itChar.key() * itChar.value();
 		quint64 charSpacingCount = itChar.value();
 		qint64 wordSpacingSum = itWord.key() * itWord.value();
@@ -688,7 +683,7 @@ VobSubInputProcessDialog::processNextPiece()
 	ui->symbolCount->setValue(1);
 
 	if(m_pieceCurrent == m_pieces.end()) {
-		QString subText;
+		RichString subText;
 		PiecePtr piecePrev;
 		foreach(PiecePtr piece, m_pieces) {
 			if(piecePrev) {
@@ -702,9 +697,12 @@ VobSubInputProcessDialog::processNextPiece()
 			piecePrev = piece;
 		}
 
-		SubtitleLine *l = new SubtitleLine((*m_frameCurrent)->subShowTime, (*m_frameCurrent)->subHideTime);
-		l->primaryDoc()->setPlainText(subText);
-		m_subtitle->insertLine(l);
+		SubtitleLine *l = m_subtitle->line((*m_frameCurrent)->index);
+		if(!l) {
+			l = new SubtitleLine((*m_frameCurrent)->subShowTime, (*m_frameCurrent)->subHideTime);
+			m_subtitle->insertLine(l);
+		}
+		l->primaryDoc()->setRichText(subText);
 
 		ui->grpText->setDisabled(true);
 		ui->grpNavButtons->setDisabled(true);
@@ -723,7 +721,7 @@ VobSubInputProcessDialog::recognizePiece()
 		if(len != normal->symbolCount)
 			continue;
 		if(m_recognizedPieces.contains(*normal)) {
-			const SString text = m_recognizedPieces.value(*normal);
+			const RichString text = m_recognizedPieces.value(*normal);
 			(*m_pieceCurrent)->text = text;
 			currentSymbolCountSet(len);
 			processNextPiece();
@@ -734,17 +732,17 @@ VobSubInputProcessDialog::recognizePiece()
 	processCurrentPiece();
 }
 
-SString
+RichString
 VobSubInputProcessDialog::currentText()
 {
 	int style = 0;
 	if(ui->styleBold->isChecked())
-		style |= SString::Bold;
+		style |= RichString::Bold;
 	if(ui->styleItalic->isChecked())
-		style |= SString::Italic;
+		style |= RichString::Italic;
 	if(ui->styleUnderline->isChecked())
-		style |= SString::Underline;
-	return SString(ui->lineEdit->text(), style);
+		style |= RichString::Underline;
+	return RichString(ui->lineEdit->text(), style);
 }
 
 VobSubInputProcessDialog::PiecePtr
@@ -814,8 +812,6 @@ VobSubInputProcessDialog::onPrevImageClicked()
 		return;
 
 	--m_frameCurrent;
-	if(m_subtitle->lastIndex() >= 0)
-		m_subtitle->removeLines(RangeList(Range(m_subtitle->lastIndex())), Both);
 
 	ui->progressBar->setValue((*m_frameCurrent)->index + 1);
 
@@ -874,9 +870,9 @@ VobSubInputProcessDialog::updateCurrentPiece()
 	ui->lineEdit->selectAll();
 
 	int style = (*m_pieceCurrent)->text.styleFlagsAt(0);
-	ui->styleBold->setChecked((style & SString::Bold) != 0);
-	ui->styleItalic->setChecked((style & SString::Italic) != 0);
-	ui->styleUnderline->setChecked((style & SString::Underline) != 0);
+	ui->styleBold->setChecked((style & RichString::Bold) != 0);
+	ui->styleItalic->setChecked((style & RichString::Italic) != 0);
+	ui->styleUnderline->setChecked((style & RichString::Underline) != 0);
 
 	ui->symbolCount->setValue((*m_pieceCurrent)->symbolCount);
 }
