@@ -1,19 +1,18 @@
 /*
     SPDX-FileCopyrightText: 2007-2009 Sergio Pistone <sergio_pistone@yahoo.com.ar>
-    SPDX-FileCopyrightText: 2010-2019 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2010-2022 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "playerwidget.h"
+
+#include "appglobal.h"
 #include "application.h"
 #include "actions/useractionnames.h"
-#include "helpers/commondefs.h"
-#include "core/richdocument.h"
-#include "core/subtitleiterator.h"
+#include "core/richtext/richdocument.h"
 #include "videoplayer/videoplayer.h"
 #include "widgets/layeredwidget.h"
-#include "widgets/textoverlaywidget.h"
 #include "widgets/attachablewidget.h"
 #include "widgets/pointingslider.h"
 #include "widgets/timeedit.h"
@@ -25,7 +24,6 @@
 
 #include <QMenu>
 #include <QPushButton>
-#include <QDesktopWidget>
 #include <QCursor>
 #include <QLabel>
 #include <QToolButton>
@@ -101,7 +99,7 @@ PlayerWidget::PlayerWidget(QWidget *parent) :
 	m_volumeSlider->setFocusPolicy(Qt::NoFocus);
 
 	QGridLayout *videoControlsLayout = new QGridLayout();
-	videoControlsLayout->setMargin(0);
+	videoControlsLayout->setContentsMargins(0, 0, 0, 0);
 	videoControlsLayout->setSpacing(2);
 	videoControlsLayout->addWidget(createToolButton(this, ACT_PLAY_PAUSE, 16), 0, 0);
 	videoControlsLayout->addWidget(createToolButton(this, ACT_STOP, 16), 0, 1);
@@ -121,7 +119,7 @@ PlayerWidget::PlayerWidget(QWidget *parent) :
 	videoControlsLayout->addWidget(m_seekSlider, 0, 15);
 
 	QGridLayout *audioControlsLayout = new QGridLayout();
-	audioControlsLayout->setMargin(0);
+	audioControlsLayout->setContentsMargins(0, 0, 0, 0);
 	audioControlsLayout->addWidget(createToolButton(this, ACT_TOGGLE_MUTED, 16), 0, 0, Qt::AlignHCenter);
 	audioControlsLayout->addWidget(m_volumeSlider, 1, 0, Qt::AlignHCenter);
 
@@ -141,7 +139,7 @@ PlayerWidget::PlayerWidget(QWidget *parent) :
 	infoControlsLayout->addWidget(m_positionEdit, 11, 0);
 
 	m_mainLayout = new QGridLayout(this);
-	m_mainLayout->setMargin(0);
+	m_mainLayout->setContentsMargins(0, 0, 0, 0);
 	m_mainLayout->setSpacing(5);
 	m_mainLayout->addWidget(m_infoControlsGroupBox, 0, 0, 2, 1);
 	m_mainLayout->addWidget(m_layeredWidget, 0, 1);
@@ -179,7 +177,7 @@ PlayerWidget::PlayerWidget(QWidget *parent) :
 	m_fsPositionLabel->setMinimumWidth(m_fsPositionLabel->width());
 
 	QHBoxLayout *fullScreenControlsLayout = new QHBoxLayout(m_fullScreenControls);
-	fullScreenControlsLayout->setMargin(0);
+	fullScreenControlsLayout->setContentsMargins(0, 0, 0, 0);
 	fullScreenControlsLayout->setSpacing(0);
 
 	const int FS_BUTTON_SIZE = 32;
@@ -238,7 +236,7 @@ PlayerWidget::PlayerWidget(QWidget *parent) :
 
 	setFullScreenMode(m_fullScreenMode);
 
-	connect(app(), &Application::actionsReady, [this](){
+	connect(app(), &Application::actionsReady, this, [this](){
 		toolButton(this, ACT_STOP)->setDefaultAction(app()->action(ACT_STOP));
 		toolButton(this, ACT_PLAY_PAUSE)->setDefaultAction(app()->action(ACT_PLAY_PAUSE));
 		toolButton(this, ACT_SEEK_BACKWARD)->setDefaultAction(app()->action(ACT_SEEK_BACKWARD));
@@ -308,8 +306,6 @@ PlayerWidget::saveConfig()
 void
 PlayerWidget::setFullScreenMode(bool fullScreenMode)
 {
-	VideoPlayer::instance()->subtitleOverlay().setRenderScale(fullScreenMode ? 1.0 : 1.2);
-
 	if(m_fullScreenMode == fullScreenMode)
 		return;
 
@@ -324,9 +320,10 @@ PlayerWidget::setFullScreenMode(bool fullScreenMode)
 		// because restoring the previous state is buggy under
 		// some desktop environments / window managers.
 
-		auto *fullScreenWidget = new QWidget;
-		auto *fullScreenLayout = new QHBoxLayout;
-		fullScreenLayout->setMargin(0);
+		auto *fullScreenWidget = new QWidget();
+		fullScreenWidget->installEventFilter(this);
+		auto *fullScreenLayout = new QHBoxLayout();
+		fullScreenLayout->setContentsMargins(0, 0, 0, 0);
 		fullScreenWidget->setLayout(fullScreenLayout);
 		m_layeredWidget->setParent(fullScreenWidget);
 		fullScreenLayout->addWidget(m_layeredWidget);
@@ -337,6 +334,8 @@ PlayerWidget::setFullScreenMode(bool fullScreenMode)
 		m_fullScreenControls->attach(m_layeredWidget);
 
 		m_fullScreenTID = startTimer(HIDE_MOUSE_MSECS);
+
+		VideoPlayer::instance()->subtitleOverlay().setBottomPadding(m_fullScreenControls->height());
 	} else {
 		if(m_fullScreenTID) {
 			killTimer(m_fullScreenTID);
@@ -353,13 +352,16 @@ PlayerWidget::setFullScreenMode(bool fullScreenMode)
 
 		m_mainLayout->addWidget(m_layeredWidget, 0, 1);
 
+		VideoPlayer::instance()->subtitleOverlay().setBottomPadding(0);
+
 		window()->show();
 	}
 }
 
 void
-PlayerWidget::timerEvent(QTimerEvent * /*event */)
+PlayerWidget::timerEvent(QTimerEvent *event)
 {
+	Q_UNUSED(event);
 	if(m_currentCursorPos != m_savedCursorPos) {
 		m_savedCursorPos = m_currentCursorPos;
 	} else if(!m_fullScreenControls->underMouse()) {
@@ -380,9 +382,8 @@ PlayerWidget::eventFilter(QObject *object, QEvent *event)
 			foreach(const QUrl &url, static_cast<QDropEvent *>(event)->mimeData()->urls()) {
 				if(url.scheme() == QLatin1String("file")) {
 					event->accept();
-					if(event->type() == QEvent::Drop) {
+					if(event->type() == QEvent::Drop)
 						app()->openVideo(url);
-					}
 					return true; // eat event
 				}
 			}
@@ -401,13 +402,18 @@ PlayerWidget::eventFilter(QObject *object, QEvent *event)
 				app()->action(ACT_TOGGLE_FULL_SCREEN)->trigger();
 				return true;
 			}
-			return app()->triggerAction(QKeySequence((keyEvent->modifiers() & ~Qt::KeypadModifier) + keyEvent->key()));
+			return app()->triggerAction(QKeySequence((keyEvent->modifiers() & ~Qt::KeypadModifier) | keyEvent->key()));
 		}
 
 		case QEvent::MouseMove: {
 			QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(event);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 			if(mouseEvent->globalPos() != m_currentCursorPos) {
 				m_currentCursorPos = mouseEvent->globalPos();
+#else
+			if(mouseEvent->globalPosition() != m_currentCursorPos) {
+				m_currentCursorPos = mouseEvent->globalPosition();
+#endif
 				if(m_layeredWidget->cursor().shape() == Qt::BlankCursor)
 					m_layeredWidget->unsetCursor();
 				if(m_fullScreenControls->isAttached())
@@ -417,9 +423,8 @@ PlayerWidget::eventFilter(QObject *object, QEvent *event)
 		}
 
 		default:
-			;
+			break;
 		}
-
 	} else if(object == m_infoControlsGroupBox || object->parent() == m_infoControlsGroupBox) {
 		if(event->type() != QEvent::MouseButtonRelease)
 			return false;
@@ -434,10 +439,18 @@ PlayerWidget::eventFilter(QObject *object, QEvent *event)
 		action->setCheckable(true);
 		action->setChecked(SCConfig::showPositionTimeEdit());
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 		if(menu.exec(mouseEvent->globalPos()) == action)
+#else
+		if(menu.exec(mouseEvent->globalPosition().toPoint()) == action)
+#endif
 			SCConfig::setShowPositionTimeEdit(!SCConfig::showPositionTimeEdit());
 
 		return true; // eat event
+	} else if(m_fullScreenMode && object == m_layeredWidget->parentWidget() && event->type() == QEvent::Close) {
+		app()->action(ACT_TOGGLE_FULL_SCREEN)->trigger();
+		event->ignore();
+		return true; // eat event
 	}
 
 	return false;
@@ -570,9 +583,11 @@ PlayerWidget::setPlayingLine(SubtitleLine *line)
 	if(m_playingLine == line)
 		return;
 
+	SubtitleTextOverlay &ovr = VideoPlayer::instance()->subtitleOverlay();
 	if(m_playingLine) {
 		disconnect(m_playingLine, &SubtitleLine::showTimeChanged, this, &PlayerWidget::setPlayingLineFromVideo);
 		disconnect(m_playingLine, &SubtitleLine::hideTimeChanged, this, &PlayerWidget::setPlayingLineFromVideo);
+		disconnect(m_playingLine, &SubtitleLine::positionChanged, &ovr, &SubtitleTextOverlay::forceRepaint);
 	}
 
 	emit playingLineChanged(m_playingLine = line);
@@ -580,9 +595,12 @@ PlayerWidget::setPlayingLine(SubtitleLine *line)
 	if(m_playingLine) {
 		connect(m_playingLine, &SubtitleLine::showTimeChanged, this, &PlayerWidget::setPlayingLineFromVideo);
 		connect(m_playingLine, &SubtitleLine::hideTimeChanged, this, &PlayerWidget::setPlayingLineFromVideo);
-		VideoPlayer::instance()->subtitleOverlay().setDoc(m_showTranslation ? m_playingLine->secondaryDoc() : m_playingLine->primaryDoc());
+		connect(m_playingLine, &SubtitleLine::positionChanged, &ovr, &SubtitleTextOverlay::forceRepaint);
+		ovr.setDoc(m_showTranslation ? m_playingLine->secondaryDoc() : m_playingLine->primaryDoc());
+		ovr.setDocRect(&m_playingLine->pos());
 	} else {
-		VideoPlayer::instance()->subtitleOverlay().setDoc(nullptr);
+		ovr.setDoc(nullptr);
+		ovr.setDocRect(nullptr);
 	}
 }
 
@@ -656,7 +674,7 @@ PlayerWidget::onPlayerFileOpenError(const QString &filePath, const QString &reas
 	QString message = i18n("<qt>There was an error opening media file %1.</qt>", filePath);
 	if(!reason.isEmpty())
 		message += "\n" + reason;
-	KMessageBox::sorry(this, message);
+	KMessageBox::error(this, message);
 }
 
 void
@@ -778,13 +796,14 @@ PlayerWidget::onPlayerVolumeChanged(double volume)
 }
 
 void
-PlayerWidget::onPlayerLeftClicked(const QPoint & /*point */)
+PlayerWidget::onPlayerLeftClicked(const QPointF &point)
 {
+	Q_UNUSED(point);
 	VideoPlayer::instance()->togglePlayPaused();
 }
 
 void
-PlayerWidget::onPlayerRightClicked(const QPoint &point)
+PlayerWidget::onPlayerRightClicked(const QPointF &point)
 {
 	static QMenu *menu = new QMenu(this);
 
@@ -833,11 +852,12 @@ PlayerWidget::onPlayerRightClicked(const QPoint &point)
 	// when using the mplayer backend. i think it's related to the fact
 	// that exec() creates a different event loop and the mplayer backend
 	// depends on the main loop for catching synchronization signals
-	menu->popup(point);
+	menu->popup(point.toPoint());
 }
 
 void
-PlayerWidget::onPlayerDoubleClicked(const QPoint & /*point */)
+PlayerWidget::onPlayerDoubleClicked(const QPointF &point)
 {
+	Q_UNUSED(point);
 	app()->toggleFullScreenMode();
 }
