@@ -13,8 +13,6 @@
 #include "actions/useractionnames.h"
 #include "dialogs/textinputdialog.h"
 #include "helpers/common.h"
-#include "helpers/fileloadhelper.h"
-#include "helpers/filetrasher.h"
 #include "scripting/scripting_rangesmodule.h"
 #include "scripting/scripting_stringsmodule.h"
 #include "scripting/scripting_subtitlemodule.h"
@@ -31,20 +29,9 @@
 #include <QKeyEvent>
 #include <QStringBuilder>
 
-#include <kio_version.h>
 #include <KMessageBox>
-#if KIO_VERSION < QT_VERSION_CHECK(5, 71, 0)
-#include <KRun>
-#endif
 #include <KActionCollection>
 #include <KLocalizedString>
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 71, 0)
-#include <KIO/OpenUrlJob>
-#include <KIO/JobUiDelegate>
-#endif
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
-#include <KIO/JobUiDelegateFactory>
-#endif
 #include <kwidgetsaddons_version.h>
 
 inline static const QDir &
@@ -302,7 +289,9 @@ public:
 
 	void removeAll()
 	{
-		beginRemoveRows(QModelIndex(), 0, m_categories.size());
+		if(m_categories.size() == 0)
+			return;
+		beginRemoveRows(QModelIndex(), 0, m_categories.size() - 1);
 		m_categories.clear();
 		m_scripts.clear();
 		endRemoveRows();
@@ -332,17 +321,36 @@ public:
 		const SCScript *script = insertSorted(&m_scripts, SCScript(path, name));
 		const QString catTitle = script->category();
 
-		int catIndex = m_categories.indexOf(catTitle);
-		if(catIndex < 0 && !catTitle.isEmpty()) {
-			catIndex = m_categories.size();
-			beginInsertRows(QModelIndex(), catIndex, catIndex + 1);
-			insertSorted(&m_categories, QString(catTitle));
+		if(catTitle.isEmpty()) {
+			// inserting to root, category list is followed by uncategorized script list
+			int scriptIndex = script - m_scripts.constData();
+			for(int i = scriptIndex - 1; i >= 0; i--) {
+				if(!m_scripts[i].category().isEmpty())
+					scriptIndex--;
+			}
+			scriptIndex += m_categories.size();
+			beginInsertRows(QModelIndex(), scriptIndex, scriptIndex);
+			endInsertRows();
+		} else {
+			// insert category root first if needed
+			int catIndex = m_categories.indexOf(catTitle);
+			if(catIndex < 0) {
+				const QString *cat = insertSorted(&m_categories, QString(catTitle));
+				catIndex = cat - m_categories.constData();
+				beginInsertRows(QModelIndex(), catIndex, catIndex);
+				endInsertRows();
+			}
+
+			// inserting to category sublist, decrease index for all scripts in different categories
+			int scriptIndex = script - m_scripts.constData();
+			for(int i = scriptIndex - 1; i >= 0; i--) {
+				if(m_scripts[i].category() != script->category())
+					scriptIndex--;
+			}
+			beginInsertRows(createIndex(catIndex, 0, quintptr(0ULL)), scriptIndex, scriptIndex + 1);
 			endInsertRows();
 		}
 
-		const int n = m_scripts.size();
-		beginInsertRows(catTitle.isEmpty() ? QModelIndex() : createIndex(catIndex, 0, quintptr(0ULL)), n - 1, n + 1);
-		endInsertRows();
 		return script;
 	}
 
@@ -399,6 +407,7 @@ ScriptsManager::ScriptsManager(QObject *parent)
 	connect(scriptsView->selectionModel(), &QItemSelectionModel::currentRowChanged, this, [&](){
 		const SCScript *s = currentScript();
 		const bool isScriptSelected = s && s->isScript();
+		const bool isFileSelected = s && QFileInfo(s->path()).isFile();
 		const bool isFileWritable = s && QFileInfo(s->path()).isWritable();
 		btnRemove->setEnabled(isFileWritable);
 		if(isFileWritable) {
@@ -408,7 +417,7 @@ ScriptsManager::ScriptsManager(QObject *parent)
 			btnEdit->setText(i18n("View"));
 			btnEdit->setIcon(QIcon::fromTheme($("document-open")));
 		}
-		btnEdit->setEnabled(isScriptSelected);
+		btnEdit->setEnabled(isFileSelected);
 		btnRun->setEnabled(isScriptSelected);
 	});
 
@@ -555,16 +564,15 @@ ScriptsManager::addScript(const QUrl &sSU)
 		scriptName = nameDlg.value();
 	}
 
-	FileLoadHelper fileLoadHelper(srcScriptUrl);
-
-	if(!fileLoadHelper.open()) {
+	QFile src(srcScriptUrl.toLocalFile());
+	if(!src.open(QIODevice::ReadOnly)) {
 		KMessageBox::error(app()->mainWindow(), i18n("There was an error opening the file <b>%1</b>.", srcScriptUrl.toString(QUrl::PreferLocalFile)));
 		return;
 	}
 
 	QFile dest(userScriptDir().absoluteFilePath(scriptName));
 	if(!dest.open(QIODevice::WriteOnly | QIODevice::Truncate)
-			|| dest.write(fileLoadHelper.file()->readAll()) == -1
+			|| dest.write(src.readAll()) == -1
 			|| !dest.flush()) {
 		KMessageBox::error(app()->mainWindow(), i18n("There was an error copying the file to <b>%1</b>.", dest.fileName()));
 		return;
@@ -584,7 +592,7 @@ ScriptsManager::removeScript(const QString &sN)
 			i18n("Do you really want to send file <b>%1</b> to the trash?", script->path()), i18n("Move to Trash")) != KMessageBox::Continue)
 		return;
 
-	if(!FileTrasher(script->path()).exec()) {
+	if(!QFile(script->path()).moveToTrash()) {
 		KMessageBox::error(app()->mainWindow(), i18n("There was an error removing the file <b>%1</b>.", script->path()));
 		return;
 	}
@@ -602,24 +610,8 @@ ScriptsManager::editScript(const QString &sN)
 	}
 
 	const QUrl scriptUrl = QUrl::fromLocalFile(script->path());
-#ifdef SC_APPIMAGE
-	{
-#elif KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
-	KIO::OpenUrlJob *job = new KIO::OpenUrlJob(scriptUrl);
-	job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, app()->mainWindow()));
-	if(!job->exec()) {
-#elif KIO_VERSION >= QT_VERSION_CHECK(5, 71, 0)
-	KIO::OpenUrlJob *job = new KIO::OpenUrlJob(scriptUrl);
-	job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, app()->mainWindow()));
-	if(!job->exec()) {
-#elif KIO_VERSION >= QT_VERSION_CHECK(5, 31, 0)
-	if(!KRun::runUrl(scriptUrl, "text/plain", app()->mainWindow(), KRun::RunFlags())) {
-#else
-	if(!KRun::runUrl(scriptUrl, "text/plain", app()->mainWindow(), false, false)) {
-#endif
-		if(!QDesktopServices::openUrl(scriptUrl))
-			KMessageBox::error(app()->mainWindow(), i18n("Could not launch external editor.\n"));
-	}
+	if(!QDesktopServices::openUrl(scriptUrl))
+		KMessageBox::error(app()->mainWindow(), i18n("Could not launch external editor.\n"));
 }
 
 void
