@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2010-2019 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2010-2022 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -30,10 +30,11 @@ public:
 private:
 	const QString & name() override;
 
+	const WaveFormat & waveFormat() const override;
 	bool init() override;
 	void cleanup() override;
 
-	void processSamples(const qint16 *sampleData, qint32 sampleCount) override;
+	void processSamples(const void *sampleData, qint32 sampleCount) override;
 	void processComplete() override;
 
 	void processUtterance();
