@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2010-2019 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2010-2022 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -195,7 +195,7 @@ StreamProcessor::findStream(int streamType, int streamIndex, bool imageSub)
 		int ret;
 		char errorText[1024];
 
-		AVCodec *dec = avcodec_find_decoder(m_avStream->codecpar->codec_id);
+		const AVCodec *dec = avcodec_find_decoder(m_avStream->codecpar->codec_id);
 		if(!dec) {
 			qWarning() << "Failed to find decoder for stream" << i;
 			return false;
@@ -448,12 +448,12 @@ StreamProcessor::processAudio()
 
 					if(m_swResample) {
 						Q_ASSERT(frameResampled != nullptr);
-						emit audioDataAvailable(frameResampled->data[0], frameSize * frameResampled->channels,
+						emit audioDataAvailable(frameResampled->data[0], qint32(frameSize * frameResampled->channels),
 							&m_audioStreamFormat, qint64(timeFrameStart + timeResampleDelay), qint64(timeFrameDuration));
 
 						drainSampleBuffer = swr_get_out_samples(m_swResample, 0) > 1000;
 					} else {
-						emit audioDataAvailable(frame->data[0], frameSize * frame->channels,
+						emit audioDataAvailable(frame->data[0], qint32(frameSize * frame->channels),
 							&m_audioStreamFormat, qint64(timeFrameStart), qint64(timeFrameDuration));
 					}
 				} while(!conversionComplete && !isInterruptionRequested() && drainSampleBuffer);
@@ -537,11 +537,10 @@ StreamProcessor::processText()
 				case SUBTITLE_ASS: {
 #if 1
 					const char *assText = sub->ass;
-					if(strncmp("Dialogue", assText, 8) != 0)
-						break;
-
+					// FIXME: did ass format change with ffmpeg6? can't find any references
+					const int textLocation = strncmp("Dialogue", assText, 8) ? 8 : 9;
 					// Dialogue: Marked, Start, End, Style, Name, MarginL, MarginR, MarginV, Effect, Text
-					for(int c = 9; c && *assText; assText++) {
+					for(int c = textLocation; c && *assText; assText++) {
 						if(*assText == ',')
 							c--;
 					}
@@ -550,7 +549,7 @@ StreamProcessor::processText()
 										  "{\\c&H0000ff&}red {\\c&H00ff00&}green {\\c&Hff0000&}blue{\\r}\\n"
 										  "Another {\\b100}bold\\h{\\i1}bolditalic{\\b0\\i0} some{\\anidfsd} unsupported tag";
 #endif
-					QString assChunk(assText);
+					QString assChunk = QString::fromUtf8(assText);
 
 					assChunk
 							.replace(QStringLiteral("\\N"), QStringLiteral("\n"))
