@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2021 Mladen Milinkovic <max@smoothware.net>
+    SPDX-FileCopyrightText: 2021-2022 Mladen Milinkovic <max@smoothware.net>
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,11 +15,16 @@ class SubtitleTest : public QObject
 {
 	Q_OBJECT
 
-	SubtitleComposer::Subtitle sub;
+public:
+	SubtitleTest();
+	virtual ~SubtitleTest();
 
 private slots:
 	void testSort_data();
 	void testSort();
+
+private:
+	QExplicitlySharedDataPointer<SubtitleComposer::Subtitle> sub;
 };
 
 #endif // SUBTITLESORTTEST_H
