@@ -36,7 +36,7 @@ private:
 	bool authenticate();
 	void authenticated();
 	bool languagesUpdate();
-	void languagesUpdated();
+	void languagesUpdated(QNetworkReply *res);
 
 private:
 	QNetworkAccessManager *m_netManager;
