@@ -79,6 +79,10 @@ GLRenderer::GLRenderer(QWidget *parent)
 	  m_idTex(nullptr),
 	  m_vaBuf(nullptr)
 {
+	// NOTE: Qt6.7 QOpenGLWidget breaks main window rendering after reparenting during fullscreen transition
+	setAttribute(Qt::WA_NativeWindow, true); // making it native window borks only parent widget rendering
+	winId(); // this should create native window immediately? and no rendering gets borked
+
 	setUpdateBehavior(NoPartialUpdate);
 }
 
@@ -172,7 +176,7 @@ GLRenderer::setFrameFormat(int width, int height, int compBits, int crWidthShift
 #else
 	const QSize sr = screen()->size();
 #endif
-	const double rr = qMin(sr.width() / width, sr.height() / height);
+	const double rr = qMin(double(sr.width()) / width, double(sr.height()) / height);
 	m_overlay->setImageSize(rr * width, rr * height);
 	delete[] m_mmOvr;
 	m_mmOvr = new quint8[(m_overlay->width() >> 1) * (m_overlay->height() >> 1) * 4];
@@ -438,7 +442,6 @@ GLRenderer::initShader()
 
 	delete m_fragShader;
 	m_fragShader = new QOpenGLShader(QOpenGLShader::Fragment, this);
-//	asGL(glUniformMatrix4fv(m_texCSLoc, 1, GL_FALSE, m_csCM.constData()));
 
 	const float *csm = m_csCM.constData();
 	QString csms;
@@ -497,7 +500,7 @@ GLRenderer::initShader()
 		qCritical() << "GLRenderer: shader linking failed:" << m_shaderProg->log();
 		return;
 	}
-	m_shaderProg->bind();
+	asGL(m_shaderProg->bind());
 
 	m_texY = m_shaderProg->uniformLocation("texY");
 	m_texU = m_shaderProg->uniformLocation("texU");
@@ -523,8 +526,9 @@ GLRenderer::initializeGL()
 	qDebug() << "OpenGL version:" << reinterpret_cast<const char *>(glGetString(GL_VERSION));
 	qDebug() << "GLSL version:" << reinterpret_cast<const char *>(glGetString(GL_SHADING_LANGUAGE_VERSION));
 
-	if(m_vao.create())
-		m_vao.bind();
+	if(m_vao.create()) {
+		asGL(m_vao.bind());
+	}
 
 	if(m_vaBuf) {
 		asGL(glDeleteBuffers(A_SIZE, m_vaBuf));
@@ -578,6 +582,12 @@ GLRenderer::initializeGL()
 
 	m_texNeedInit = true;
 	m_csNeedInit = true;
+
+	asGL(glBindBuffer(GL_ARRAY_BUFFER, 0));
+
+	if(m_vao.isCreated()) {
+		asGL(m_vao.release());
+	}
 }
 
 void
@@ -606,53 +616,60 @@ GLRenderer::paintGL()
 		asGL(glPixelStorei(GL_UNPACK_ALIGNMENT, 1));
 	}
 
-	if(m_csNeedInit)
+	if(m_csNeedInit) {
 		initShader();
+	} else {
+		asGL(m_shaderProg->bind());
+	}
 
 	uploadYUV();
 	uploadSubtitle();
 
+	if(m_vao.isCreated()) {
+		asGL(m_vao.bind());
+	}
+
 	asGL(glDrawArrays(GL_TRIANGLE_STRIP, 0, 4));
 
+	if(m_vao.isCreated()) {
+		asGL(m_vao.release());
+	}
+
+	asGL(m_shaderProg->release());
+
 	m_texNeedInit = false;
 	m_csNeedInit = false;
 }
 
 template<class T, int D>
 void
-GLRenderer::uploadMM(int texWidth, int texHeight, T *texBuf, const T *texSrc)
+GLRenderer::uploadMM(int texWidth, int texHeight, T *texBuf, const T *texSrc, int vpWidth, int vpHeight)
 {
-	int level = 0;
 	for(;;) {
-		if(m_texNeedInit) {
-			if(D == 1) {
-				asGL(glTexImage2D(GL_TEXTURE_2D, level, m_glFormat, texWidth, texHeight, 0, GL_RED, m_glType, texSrc));
-			} else { // D == 4
-				asGL(glTexImage2D(GL_TEXTURE_2D, level, GL_RGBA8, texWidth, texHeight, 0, TEXTURE_RGB_FORMAT, GL_UNSIGNED_BYTE, texSrc));
-			}
-		} else {
-			if(D == 1) {
-				asGL(glTexSubImage2D(GL_TEXTURE_2D, level, 0, 0, texWidth, texHeight, GL_RED, m_glType, texSrc));
-			} else { // D == 4
-				asGL(glTexSubImage2D(GL_TEXTURE_2D, level, 0, 0, texWidth, texHeight, TEXTURE_RGB_FORMAT, GL_UNSIGNED_BYTE, texSrc));
-			}
-		}
-
 		const int srcStride = texWidth * D;
 		const int srcStridePD = srcStride + D;
-		const int srcStrideDiff = texWidth & 1;
-		texWidth >>= 1;
-		texHeight >>= 1;
-		if(texWidth < m_vpWidth && texHeight < m_vpHeight) {
+		const int newWidth = texWidth >> 1;
+		const int newHeight = texHeight >> 1;
+		if(newWidth < vpWidth && newHeight < vpHeight) {
 			if(m_texNeedInit) {
-				asGL(glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR_MIPMAP_LINEAR));
+				asGL(glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR));
 				asGL(glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR));
-				asGL(glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_BASE_LEVEL, 0));
-				asGL(glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAX_LEVEL, level));
+				if(D == 1) {
+					asGL(glTexImage2D(GL_TEXTURE_2D, 0, m_glFormat, texWidth, texHeight, 0, GL_RED, m_glType, texSrc));
+				} else { // D == 4
+					asGL(glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA8, texWidth, texHeight, 0, TEXTURE_RGB_FORMAT, GL_UNSIGNED_BYTE, texSrc));
+				}
+			} else {
+				if(D == 1) {
+					asGL(glTexSubImage2D(GL_TEXTURE_2D, 0, 0, 0, texWidth, texHeight, GL_RED, m_glType, texSrc));
+				} else { // D == 4
+					asGL(glTexSubImage2D(GL_TEXTURE_2D, 0, 0, 0, texWidth, texHeight, TEXTURE_RGB_FORMAT, GL_UNSIGNED_BYTE, texSrc));
+				}
 			}
 			break;
 		}
-		level++;
+		texWidth = newWidth;
+		texHeight = newHeight;
 
 		T *dst = texBuf;
 		const int texStride = texWidth * D;
@@ -673,7 +690,7 @@ GLRenderer::uploadMM(int texWidth, int texHeight, T *texBuf, const T *texSrc)
 					texSrc += D + 1;
 				}
 			}
-			texSrc += srcStride + srcStrideDiff;
+			texSrc += srcStride;
 		}
 		texSrc = texBuf;
 	}
@@ -691,9 +708,9 @@ GLRenderer::uploadYUV()
 	asGL(glActiveTexture(GL_TEXTURE0 + ID_Y));
 	asGL(glBindTexture(GL_TEXTURE_2D, m_idTex[ID_Y]));
 	if(m_glType == GL_UNSIGNED_BYTE)
-		uploadMM<quint8, 1>(m_bufWidth, m_bufHeight, m_mmYUV, m_pixels[0]);
+		uploadMM<quint8, 1>(m_bufWidth, m_bufHeight, m_mmYUV, m_pixels[0], m_vpWidth, m_vpHeight);
 	else
-		uploadMM<quint16, 1>(m_bufWidth, m_bufHeight, reinterpret_cast<quint16 *>(m_mmYUV), reinterpret_cast<quint16 *>(m_pixels[0]));
+		uploadMM<quint16, 1>(m_bufWidth, m_bufHeight, reinterpret_cast<quint16 *>(m_mmYUV), reinterpret_cast<quint16 *>(m_pixels[0]), m_vpWidth, m_vpHeight);
 	if(m_texNeedInit) {
 		asGL(glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE));
 		asGL(glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE));
@@ -704,9 +721,9 @@ GLRenderer::uploadYUV()
 	asGL(glActiveTexture(GL_TEXTURE0 + ID_U));
 	asGL(glBindTexture(GL_TEXTURE_2D, m_idTex[ID_U]));
 	if(m_glType == GL_UNSIGNED_BYTE)
-		uploadMM<quint8, 1>(m_crWidth, m_crHeight, m_mmYUV, m_pixels[1]);
+		uploadMM<quint8, 1>(m_crWidth, m_crHeight, m_mmYUV, m_pixels[1], m_vpWidth, m_vpHeight);
 	else
-		uploadMM<quint16, 1>(m_crWidth, m_crHeight, reinterpret_cast<quint16 *>(m_mmYUV), reinterpret_cast<quint16 *>(m_pixels[1]));
+		uploadMM<quint16, 1>(m_crWidth, m_crHeight, reinterpret_cast<quint16 *>(m_mmYUV), reinterpret_cast<quint16 *>(m_pixels[1]), m_vpWidth, m_vpHeight);
 	if(m_texNeedInit) {
 		asGL(glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE));
 		asGL(glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE));
@@ -717,9 +734,9 @@ GLRenderer::uploadYUV()
 	asGL(glActiveTexture(GL_TEXTURE0 + ID_V));
 	asGL(glBindTexture(GL_TEXTURE_2D, m_idTex[ID_V]));
 	if(m_glType == GL_UNSIGNED_BYTE)
-		uploadMM<quint8, 1>(m_crWidth, m_crHeight, m_mmYUV, m_pixels[2]);
+		uploadMM<quint8, 1>(m_crWidth, m_crHeight, m_mmYUV, m_pixels[2], m_vpWidth, m_vpHeight);
 	else
-		uploadMM<quint16, 1>(m_crWidth, m_crHeight, reinterpret_cast<quint16 *>(m_mmYUV), reinterpret_cast<quint16 *>(m_pixels[2]));
+		uploadMM<quint16, 1>(m_crWidth, m_crHeight, reinterpret_cast<quint16 *>(m_mmYUV), reinterpret_cast<quint16 *>(m_pixels[2]), m_vpWidth, m_vpHeight);
 	if(m_texNeedInit) {
 		asGL(glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE));
 		asGL(glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE));
@@ -746,7 +763,7 @@ GLRenderer::uploadSubtitle()
 	// overlay
 	asGL(glActiveTexture(GL_TEXTURE0 + ID_OVR));
 	asGL(glBindTexture(GL_TEXTURE_2D, m_idTex[ID_OVR]));
-	uploadMM<quint8, 4>(img.width(), img.height(), m_mmOvr, img.constBits());
+	uploadMM<quint8, 4>(img.width(), img.height(), m_mmOvr, img.constBits(), m_vpWidth / rs, m_vpHeight / rs);
 	if(m_texNeedInit) {
 		asGL(glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_BORDER));
 		asGL(glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_BORDER));
